# 20221006_src3_test_nodes

DL1ab with tuned configuration
(DL1ab + merge DL1)

lstchain config taken from 2022-06-01 prod


## command-line:
```
lstmcpipe_generate_config PathConfigAllSkyTestingDL1ab --prod_id 20221006_src3_test_nodes --kwargs source_prod_id=20220902_crab_test_nodes dec=3476  
```

